@@ -5,7 +5,7 @@ from functools import partial
 from typing import Any, Callable, Protocol
 
 from vsaa import Nnedi3
-from vskernels import Catrom, Kernel, Scaler
+from vskernels import Catrom, KernelT, Scaler, Kernel
 from vstools import F_VD, get_w, vs
 
 from .types import Resolution
@@ -31,7 +31,10 @@ class _GeneriScaleWithShift(Protocol):
 
 @dataclass
 class GenericScaler(Scaler):
-    kernel: type[Kernel] | Kernel = field(default_factory=lambda: Catrom(), kw_only=True)
+    kernel: KernelT = field(default_factory=lambda: Catrom, kw_only=True)
+
+    def __post_init__(self) -> None:
+        self._kernel = Kernel.ensure_obj(self.kernel, self.__class__)
 
     def __init__(
         self, func: _GeneriScaleNoShift | _GeneriScaleWithShift | F_VD, **kwargs: Any
@@ -58,7 +61,7 @@ class GenericScaler(Scaler):
         except BaseException:
             scaled = self.func(clip, width=width, height=height, **kwargs)
 
-        return self.kernel.shift(scaled, shift)
+        return self._kernel.shift(scaled, shift)
 
 
 def scale_var_clip(
